===========
Filesystems
===========

|PyPI| |Pythons| |CI|

.. |PyPI| image:: https://img.shields.io/pypi/v/filesystems.svg
   :alt: PyPI version
   :target: https://pypi.python.org/pypi/filesystems

.. |Pythons| image:: https://img.shields.io/pypi/pyversions/filesystems.svg
   :alt: Supported Python versions
   :target: https://pypi.python.org/pypi/filesystems

.. |CI| image:: https://github.com/Julian/Filesystems/workflows/CI/badge.svg
  :alt: Build status
  :target: https://github.com/Julian/Filesystems/actions?query=workflow%3ACI
